@@ -605,17 +605,24 @@ class CPModuleTest(ModuleCase):
         open(  # pylint: disable=resource-leakage
             log_to_xfer, "w", encoding="utf-8"
         ).close()
+        tgt_cache_file = os.path.join(
+            RUNTIME_VARS.TMP,
+            "master-minion-root",
+            "cache",
+            "minions",
+            "minion",
+            "files",
+            RUNTIME_VARS.TMP,
+            log_to_xfer,
+        )
         try:
             self.run_function("cp.push", [log_to_xfer])
             tgt_cache_file = os.path.join(
-                RUNTIME_VARS.TMP,
-                "master-minion-root",
-                "cache",
+                RUNTIME_VARS.RUNTIME_CONFIGS["master"]["cachedir"],
                 "minions",
                 "minion",
                 "files",
-                RUNTIME_VARS.TMP,
-                log_to_xfer,
+                os.path.splitdrive(os.path.normpath(log_to_xfer.lstrip(os.sep)))[1],
             )
             self.assertTrue(
                 os.path.isfile(tgt_cache_file), "File was not cached on the master"
