@@ -2,13 +2,13 @@ import hashlib
 import urllib.parse
 
 import pytest
+from tornado.httpclient import HTTPError, HTTPRequest
+from tornado.websocket import websocket_connect
 
 import salt.netapi.rest_tornado as rest_tornado
 import salt.utils.json
 import salt.utils.yaml
 from salt.config import DEFAULT_HASH_TYPE
-from salt.ext.tornado.httpclient import HTTPError, HTTPRequest
-from salt.ext.tornado.websocket import websocket_connect
 
 pytestmark = [
     pytest.mark.destructive_test,
@@ -17,7 +17,7 @@ pytestmark = [
 
 
 @pytest.fixture
-def app(client_config):
+def app(client_config, io_loop):
     client_config.setdefault("rest_tornado", {})["websockets"] = True
     return rest_tornado.get_application(client_config)
 
@@ -28,7 +28,11 @@ def http_server_port(http_server):
 
 
 async def test_websocket_handler_upgrade_to_websocket(
-    http_client, auth_creds, content_type_map, http_server_port
+    http_client,
+    auth_creds,
+    content_type_map,
+    http_server_port,
+    io_loop,
 ):
     response = await http_client.fetch(
         "/login",
@@ -42,12 +46,12 @@ async def test_websocket_handler_upgrade_to_websocket(
     request = HTTPRequest(
         url, headers={"Origin": "http://example.com", "Host": "example.com"}
     )
-    ws = await websocket_connect(request)
-    ws.write_message("websocket client ready")
+    ws = await websocket_connect(request, connect_timeout=None)
+    await ws.write_message("websocket client ready")
     ws.close()
 
 
-async def test_websocket_handler_bad_token(client_config, http_server):
+async def test_websocket_handler_bad_token(client_config, http_server, io_loop):
     """
     A bad token should returns a 401 during a websocket connect
     """
@@ -67,7 +71,7 @@ async def test_websocket_handler_bad_token(client_config, http_server):
 
 
 async def test_websocket_handler_cors_origin_wildcard(
-    app, http_client, auth_creds, content_type_map, http_server_port
+    app, http_client, auth_creds, content_type_map, http_server_port, io_loop
 ):
     app.mod_opts["cors_origin"] = "*"
     response = await http_client.fetch(
@@ -88,7 +92,7 @@ async def test_websocket_handler_cors_origin_wildcard(
 
 
 async def test_cors_origin_single(
-    app, http_client, auth_creds, content_type_map, http_server_port
+    app, http_client, auth_creds, content_type_map, http_server_port, io_loop
 ):
     app.mod_opts["cors_origin"] = "http://example.com"
     response = await http_client.fetch(
@@ -119,7 +123,7 @@ async def test_cors_origin_single(
 
 
 async def test_cors_origin_multiple(
-    app, http_client, auth_creds, content_type_map, http_server_port
+    app, http_client, auth_creds, content_type_map, http_server_port, io_loop
 ):
     app.mod_opts["cors_origin"] = ["http://example.com", "http://foo.bar"]
 
