@@ -2,6 +2,7 @@ import pytest
 
 from salt.pillar.git_pillar import ext_pillar
 from salt.utils.immutabletypes import ImmutableDict, ImmutableList
+from salt.utils.odict import OrderedDict
 from tests.support.mock import patch
 
 pytestmark = [
@@ -260,3 +261,38 @@ def test_gitpython_multiple_2(gitpython_pillar_opts, grains):
 @skipif_no_pygit2
 def test_pygit2_multiple_2(pygit2_pillar_opts, grains):
     _test_multiple_2(pygit2_pillar_opts, grains)
+
+
+def _test_multiple_slash_in_branch_name(pillar_opts, grains):
+    pillar_opts["pillarenv"] = "doggy/moggy"
+    data = _get_ext_pillar(
+        "minion",
+        pillar_opts,
+        grains,
+        "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        "other https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
+    )
+    assert data == {
+        "key": "data",
+        "foo": OrderedDict(
+            [
+                ("animals", OrderedDict([("breed", "seadog")])),
+                (
+                    "feature/baz",
+                    OrderedDict(
+                        [("test1", "dog"), ("test2", "kat"), ("test3", "gerbil")]
+                    ),
+                ),
+            ]
+        ),
+    }
+
+
+@skipif_no_gitpython
+def test_gitpython_multiple_slash_in_branch_name(gitpython_pillar_opts, grains):
+    _test_multiple_slash_in_branch_name(gitpython_pillar_opts, grains)
+
+
+@skipif_no_pygit2
+def test_pygit2_multiple_slash_in_branch_name(pygit2_pillar_opts, grains):
+    _test_multiple_slash_in_branch_name(pygit2_pillar_opts, grains)
