@@ -17,15 +17,74 @@ def configure_loader_modules():
     }
 
 
-def test__check_directory_win_owner(tmp_path):
-    path = str(tmp_path)
+@pytest.fixture
+def temp_path(tmp_path):
+
+    # Ownership is not inherited but permissions are, so we shouldn't have to
+    # set ownership. Ownership is determined by the user creating the directory.
+    # An administrator account will set the owner as the Administrators group.
+    # A non-administrator account will set the user itself as the owner.
+
+    # Create a directory and set the permissions to make sure they're the only
+    # ones (reset_perms=True) and not inherited (protected=True)
+    tmp_path.mkdir(parents=True, exist_ok=True)
+    win_dacl.set_permissions(
+        obj_name=str(tmp_path),
+        principal="Administrators",
+        permissions="full_control",
+        access_mode="grant",
+        reset_perms=True,
+        protected=True,
+    )
+    perms = {
+        "Inherited": {},
+        "Not Inherited": {
+            "Administrators": {
+                "grant": {
+                    "applies to": "This folder, subfolders and files",
+                    "permissions": "Full control",
+                }
+            }
+        },
+    }
+    # Verify perms and inheritance
+    assert win_dacl.get_permissions(obj_name=str(tmp_path)) == perms
+    assert not win_dacl.get_inheritance(obj_name=str(tmp_path))
+
+    # Now we create a directory for testing that does inherit those permissions
+    # from the above, new parent directory
+    test_dir = tmp_path / "test_dir"
+    test_dir.mkdir()
+
+    # We want to make sure inheritance is enabled
+    assert win_dacl.get_inheritance(obj_name=str(test_dir))
+
+    # We want to make sure the test directory inherited permissions from the
+    # parent directory
+    perms = {
+        "Inherited": {
+            "Administrators": {
+                "grant": {
+                    "applies to": "This folder, subfolders and files",
+                    "permissions": "Full control",
+                }
+            }
+        },
+        "Not Inherited": {},
+    }
+    assert win_dacl.get_permissions(obj_name=str(test_dir)) == perms
+    yield test_dir
+
+
+def test__check_directory_win_owner(temp_path):
+    path = str(temp_path)
     _, comment, changes = file._check_directory_win(name=path, win_owner="Everyone")
     assert path in comment
     assert changes == {"owner": "Everyone"}
 
 
-def test__check_directory_win_grant_perms_basic(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_grant_perms_basic(temp_path):
+    path = str(temp_path)
     perms = {
         "Guest": {
             "applies_to": "this_folder_subfolders_files",
@@ -45,8 +104,8 @@ def test__check_directory_win_grant_perms_basic(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_grant_perms_basic_existing_user(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_grant_perms_basic_existing_user(temp_path):
+    path = str(temp_path)
     win_dacl.set_permissions(
         obj_name=path,
         principal="Guest",
@@ -60,8 +119,8 @@ def test__check_directory_win_grant_perms_basic_existing_user(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_grant_perms_advanced(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_grant_perms_advanced(temp_path):
+    path = str(temp_path)
     perms = {
         "Guest": {
             "applies_to": "this_folder_subfolders_files",
@@ -81,8 +140,8 @@ def test__check_directory_win_grant_perms_advanced(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_grant_perms_advanced_existing_user(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_grant_perms_advanced_existing_user(temp_path):
+    path = str(temp_path)
     win_dacl.set_permissions(
         obj_name=path,
         principal="Guest",
@@ -105,8 +164,8 @@ def test__check_directory_win_grant_perms_advanced_existing_user(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_grant_perms_basic_no_applies_to(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_grant_perms_basic_no_applies_to(temp_path):
+    path = str(temp_path)
     perms = {"Guest": {"perms": "full_control"}}
     expected = {"grant_perms": {"Guest": {"permissions": "full_control"}}}
     _, comment, changes = file._check_directory_win(name=path, win_perms=perms)
@@ -114,8 +173,8 @@ def test__check_directory_win_grant_perms_basic_no_applies_to(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_deny_perms_basic(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_deny_perms_basic(temp_path):
+    path = str(temp_path)
     perms = {
         "Guest": {
             "applies_to": "this_folder_subfolders_files",
@@ -135,8 +194,8 @@ def test__check_directory_win_deny_perms_basic(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_deny_perms_basic_existing_user(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_deny_perms_basic_existing_user(temp_path):
+    path = str(temp_path)
     win_dacl.set_permissions(
         obj_name=path,
         principal="Guest",
@@ -150,8 +209,8 @@ def test__check_directory_win_deny_perms_basic_existing_user(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_deny_perms_advanced(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_deny_perms_advanced(temp_path):
+    path = str(temp_path)
     perms = {
         "Guest": {
             "applies_to": "this_folder_subfolders_files",
@@ -171,8 +230,8 @@ def test__check_directory_win_deny_perms_advanced(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_deny_perms_advanced_existing_user(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_deny_perms_advanced_existing_user(temp_path):
+    path = str(temp_path)
     win_dacl.set_permissions(
         obj_name=path,
         principal="Guest",
@@ -195,8 +254,8 @@ def test__check_directory_win_deny_perms_advanced_existing_user(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_deny_perms_basic_no_applies_to(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_deny_perms_basic_no_applies_to(temp_path):
+    path = str(temp_path)
     perms = {"Guest": {"perms": "full_control"}}
     expected = {"deny_perms": {"Guest": {"permissions": "full_control"}}}
     _, comment, changes = file._check_directory_win(name=path, win_deny_perms=perms)
@@ -204,32 +263,32 @@ def test__check_directory_win_deny_perms_basic_no_applies_to(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_win_inheritance(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_inheritance(temp_path):
+    path = str(temp_path)
     expected = {}
     _, comment, changes = file._check_directory_win(name=path, win_inheritance=True)
     assert path in comment
     assert changes == expected
 
 
-def test__check_directory_win_inheritance_false(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_win_inheritance_false(temp_path):
+    path = str(temp_path)
     expected = {"inheritance": False}
     _, comment, changes = file._check_directory_win(name=path, win_inheritance=False)
     assert path in comment
     assert changes == expected
 
 
-def test__check_directory_reset_no_non_inherited_users(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_reset_no_non_inherited_users(temp_path):
+    path = str(temp_path)
     expected = {}
     _, comment, changes = file._check_directory_win(name=path, win_perms_reset=True)
     assert path in comment
     assert changes == expected
 
 
-def test__check_directory_reset_non_inherited_users_grant(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_reset_non_inherited_users_grant(temp_path):
+    path = str(temp_path)
     win_dacl.set_permissions(
         obj_name=path,
         principal="Guest",
@@ -252,8 +311,8 @@ def test__check_directory_reset_non_inherited_users_grant(tmp_path):
     assert changes == expected
 
 
-def test__check_directory_reset_non_inherited_users_deny(tmp_path):
-    path = str(tmp_path)
+def test__check_directory_reset_non_inherited_users_deny(temp_path):
+    path = str(temp_path)
     win_dacl.set_permissions(
         obj_name=path,
         principal="Guest",
