@@ -5,6 +5,7 @@ import pytest
 from salt.pillar.git_pillar import GLOBAL_ONLY, PER_REMOTE_ONLY, PER_REMOTE_OVERRIDES
 from salt.utils.gitfs import GitPillar, GitPython, Pygit2
 from salt.utils.immutabletypes import ImmutableDict, ImmutableList
+from salt.utils.platform import get_machine_identifier as _get_machine_identifier
 
 pytestmark = [
     pytest.mark.windows_whitelisted,
@@ -31,6 +32,8 @@ except ImportError:
 skipif_no_gitpython = pytest.mark.skipif(not HAS_GITPYTHON, reason="Missing gitpython")
 skipif_no_pygit2 = pytest.mark.skipif(not HAS_PYGIT2, reason="Missing pygit2")
 
+testgitfs = "https://github.com/saltstack/salt-test-pillar-gitfs.git"
+
 
 @pytest.fixture
 def pillar_opts(salt_factories, tmp_path):
@@ -71,9 +74,7 @@ def _get_pillar(opts, *remotes):
 
 @skipif_no_gitpython
 def test_gitpython_pillar_provider(gitpython_pillar_opts):
-    p = _get_pillar(
-        gitpython_pillar_opts, "https://github.com/saltstack/salt-test-pillar-gitfs.git"
-    )
+    p = _get_pillar(gitpython_pillar_opts, testgitfs)
     assert len(p.remotes) == 1
     assert p.provider == "gitpython"
     assert isinstance(p.remotes[0], GitPython)
@@ -81,18 +82,14 @@ def test_gitpython_pillar_provider(gitpython_pillar_opts):
 
 @skipif_no_pygit2
 def test_pygit2_pillar_provider(pygit2_pillar_opts):
-    p = _get_pillar(
-        pygit2_pillar_opts, "https://github.com/saltstack/salt-test-pillar-gitfs.git"
-    )
+    p = _get_pillar(pygit2_pillar_opts, testgitfs)
     assert len(p.remotes) == 1
     assert p.provider == "pygit2"
     assert isinstance(p.remotes[0], Pygit2)
 
 
 def _test_env(opts):
-    p = _get_pillar(
-        opts, "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git"
-    )
+    p = _get_pillar(opts, f"__env__ {testgitfs}")
     assert len(p.remotes) == 1
     p.checkout()
     repo = p.remotes[0]
@@ -101,9 +98,7 @@ def _test_env(opts):
     for f in (".gitignore", "README.md", "file.sls", "top.sls"):
         assert f in files
     opts["pillarenv"] = "main"
-    p2 = _get_pillar(
-        opts, "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git"
-    )
+    p2 = _get_pillar(opts, f"__env__ {testgitfs}")
     assert len(p.remotes) == 1
     p2.checkout()
     repo2 = p2.remotes[0]
@@ -164,9 +159,9 @@ def test_pygit2_checkout_fetch_on_fail(pygit2_pillar_opts):
 def _test_multiple_repos(opts):
     p = _get_pillar(
         opts,
-        "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git",
-        "main https://github.com/saltstack/salt-test-pillar-gitfs.git",
-        "branch https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        f"__env__ {testgitfs}",
+        f"main {testgitfs}",
+        f"branch {testgitfs}",
         "__env__ https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
         "other https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
     )
@@ -178,9 +173,9 @@ def _test_multiple_repos(opts):
 
     p2 = _get_pillar(
         opts,
-        "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git",
-        "main https://github.com/saltstack/salt-test-pillar-gitfs.git",
-        "branch https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        f"__env__ {testgitfs}",
+        f"main {testgitfs}",
+        f"branch {testgitfs}",
         "__env__ https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
         "other https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
     )
@@ -193,9 +188,9 @@ def _test_multiple_repos(opts):
     opts["pillarenv"] = "main"
     p3 = _get_pillar(
         opts,
-        "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git",
-        "main https://github.com/saltstack/salt-test-pillar-gitfs.git",
-        "branch https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        f"__env__ {testgitfs}",
+        f"main {testgitfs}",
+        f"branch {testgitfs}",
         "__env__ https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
         "other https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
     )
@@ -226,15 +221,13 @@ def test_pygit2_multiple_repos(pygit2_pillar_opts):
 def _test_fetch_request(opts):
     p = _get_pillar(
         opts,
-        "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        f"__env__ {testgitfs}",
         "other https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
     )
     frequest = os.path.join(p.remotes[0].get_salt_working_dir(), "fetch_request")
     frequest_other = os.path.join(p.remotes[1].get_salt_working_dir(), "fetch_request")
     opts["pillarenv"] = "main"
-    p2 = _get_pillar(
-        opts, "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git"
-    )
+    p2 = _get_pillar(opts, f"__env__ {testgitfs}")
     frequest2 = os.path.join(p2.remotes[0].get_salt_working_dir(), "fetch_request")
     assert frequest != frequest2
     assert os.path.isfile(frequest) is False
@@ -276,15 +269,13 @@ def test_pygit2_fetch_request(pygit2_pillar_opts):
 def _test_clear_old_remotes(opts):
     p = _get_pillar(
         opts,
-        "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        f"__env__ {testgitfs}",
         "other https://github.com/saltstack/salt-test-pillar-gitfs-2.git",
     )
     repo = p.remotes[0]
     repo2 = p.remotes[1]
     opts["pillarenv"] = "main"
-    p2 = _get_pillar(
-        opts, "__env__ https://github.com/saltstack/salt-test-pillar-gitfs.git"
-    )
+    p2 = _get_pillar(opts, f"__env__ {testgitfs}")
     repo3 = p2.remotes[0]
     assert os.path.isdir(repo.get_cachedir()) is True
     assert os.path.isdir(repo2.get_cachedir()) is True
@@ -312,7 +303,7 @@ def test_pygit2_clear_old_remotes(pygit2_pillar_opts):
 def _test_remote_map(opts):
     p = _get_pillar(
         opts,
-        "https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        testgitfs,
     )
     p.fetch_remotes()
     assert len(p.remotes) == 1
@@ -334,22 +325,27 @@ def test_pygit2_remote_map(pygit2_pillar_opts):
 def _test_lock(opts):
     p = _get_pillar(
         opts,
-        "https://github.com/saltstack/salt-test-pillar-gitfs.git",
+        testgitfs,
     )
     p.fetch_remotes()
     assert len(p.remotes) == 1
     repo = p.remotes[0]
+    mach_id = _get_machine_identifier().get("machine_id", "no_machine_id_available")
     assert repo.get_salt_working_dir() in repo._get_lock_file()
     assert repo.lock() == (
         [
-            "Set update lock for git_pillar remote 'https://github.com/saltstack/salt-test-pillar-gitfs.git'"
+            (
+                f"Set update lock for git_pillar remote '{testgitfs}' on machine_id '{mach_id}'"
+            )
         ],
         [],
     )
     assert os.path.isfile(repo._get_lock_file())
     assert repo.clear_lock() == (
         [
-            "Removed update lock for git_pillar remote 'https://github.com/saltstack/salt-test-pillar-gitfs.git'"
+            (
+                f"Removed update lock for git_pillar remote '{testgitfs}' on machine_id '{mach_id}'"
+            )
         ],
         [],
     )
