@@ -3,6 +3,8 @@ import shutil
 import pytest
 from saltfactories.utils import random_string
 
+from tests.conftest import FIPS_TESTRUN
+
 
 @pytest.fixture(scope="module")
 def pillar_state_tree(tmp_path_factory):
@@ -36,6 +38,12 @@ def peer_salt_master(
     factory = salt_factories.salt_master_daemon(
         random_string("peer-comm-master", uppercase=False),
         defaults=peer_salt_master_config,
+        overrides={
+            "fips_mode": FIPS_TESTRUN,
+            "publish_signing_algorithm": (
+                "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+            ),
+        },
     )
     with factory.started():
         yield factory
@@ -47,6 +55,11 @@ def peer_salt_minion_1(peer_salt_master):
     factory = peer_salt_master.salt_minion_daemon(
         random_string("peer-comm-minion-1", uppercase=False),
         defaults={"open_mode": True, "grains": {"hello_peer": "beer"}},
+        overrides={
+            "fips_mode": FIPS_TESTRUN,
+            "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+            "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+        },
     )
     with factory.started():
         # Sync All
@@ -62,6 +75,11 @@ def peer_salt_minion_2(peer_salt_master):
     factory = peer_salt_master.salt_minion_daemon(
         random_string("peer-comm-minion-2", uppercase=False),
         defaults={"open_mode": True},
+        overrides={
+            "fips_mode": FIPS_TESTRUN,
+            "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+            "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+        },
     )
     with factory.started():
         # Sync All
@@ -77,6 +95,11 @@ def peer_salt_minion_3(peer_salt_master):
     factory = peer_salt_master.salt_minion_daemon(
         random_string("peer-comm-minion-3", uppercase=False),
         defaults={"open_mode": True},
+        overrides={
+            "fips_mode": FIPS_TESTRUN,
+            "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+            "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+        },
     )
     with factory.started():
         # Sync All
