@@ -1,5 +1,7 @@
 import time
 
+from tests.conftest import FIPS_TESTRUN
+
 
 def test_reauth(salt_master_factory, event_listener):
     """
@@ -23,12 +25,23 @@ def test_reauth(salt_master_factory, event_listener):
     event_listener.register_auth_event_handler("test_reauth-master", handler)
     master = salt_master_factory.salt_master_daemon(
         "test_reauth-master",
-        overrides={"log_level": "info"},
+        overrides={
+            "log_level": "info",
+            "fips_mode": FIPS_TESTRUN,
+            "publish_signing_algorithm": (
+                "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+            ),
+        },
     )
     sls_tempfile = master.state_tree.base.temp_file(f"{sls_name}.sls", sls_contents)
     minion = master.salt_minion_daemon(
         "test_reauth-minion",
-        overrides={"log_level": "info"},
+        overrides={
+            "log_level": "info",
+            "fips_mode": FIPS_TESTRUN,
+            "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+            "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+        },
     )
     cli = master.salt_cli()
     start_time = time.time()
