@@ -2,6 +2,8 @@ import shutil
 
 import pytest
 
+from tests.conftest import FIPS_TESTRUN
+
 
 @pytest.fixture(scope="package")
 def pillar_state_tree(tmp_path_factory):
@@ -22,8 +24,16 @@ def pillar_salt_master(salt_factories, pillar_state_tree):
             {"extra_minion_data_in_pillar": "*"},
         ],
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "publish_signing_algorithm": (
+            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+        ),
+    }
     factory = salt_factories.salt_master_daemon(
-        "pillar-cache-functional-master", defaults=config_defaults
+        "pillar-cache-functional-master",
+        defaults=config_defaults,
+        overrides=config_overrides,
     )
     with factory.started():
         yield factory
@@ -32,9 +42,15 @@ def pillar_salt_master(salt_factories, pillar_state_tree):
 @pytest.fixture(scope="package")
 def pillar_salt_minion(pillar_salt_master):
     assert pillar_salt_master.is_running()
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     factory = pillar_salt_master.salt_minion_daemon(
         "pillar-cache-functional-minion-1",
         defaults={"open_mode": True, "hi": "there", "pass_to_ext_pillars": ["hi"]},
+        overrides=config_overrides,
     )
     with factory.started():
         # Sync All
