@@ -1,11 +1,11 @@
 import pytest
 
 pytestmark = [
-    pytest.mark.skip_unless_on_linux,
+    pytest.mark.skip_on_windows,
 ]
 
 
-def test_salt_api(api_request, salt_master, install_salt):
+def test_salt_api(api_request, install_salt, salt_master):
     """
     Test running a command against the salt api
     """
