@@ -14,7 +14,7 @@ log = logging.getLogger(__name__)
 
 
 @pytest.fixture(scope="package")
-def salt_mm_master_1(request, salt_factories):
+def _salt_mm_master_1(request, salt_factories):
     config_defaults = {
         "open_mode": True,
         "transport": request.config.getoption("--transport"),
@@ -38,23 +38,32 @@ def salt_mm_master_1(request, salt_factories):
         overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=info"],
     )
+    # Start the factory so the key files will be generated. After, we'll yeild
+    # the factory and the deamon will not be running.
     with factory.started(start_timeout=120):
-        yield factory
+        pass
+    yield factory
 
 
-@pytest.fixture(scope="package")
+@pytest.fixture
+def salt_mm_master_1(_salt_mm_master_1):
+    with _salt_mm_master_1.started(start_timeout=120):
+        yield _salt_mm_master_1
+
+
+@pytest.fixture
 def mm_master_1_salt_cli(salt_mm_master_1):
     return salt_mm_master_1.salt_cli(timeout=120)
 
 
 @pytest.fixture(scope="package")
-def salt_mm_master_2(salt_factories, salt_mm_master_1):
+def _salt_mm_master_2(salt_factories, _salt_mm_master_1):
     if salt.utils.platform.is_darwin() or salt.utils.platform.is_freebsd():
         subprocess.check_output(["ifconfig", "lo0", "alias", "127.0.0.2", "up"])
 
     config_defaults = {
         "open_mode": True,
-        "transport": salt_mm_master_1.config["transport"],
+        "transport": _salt_mm_master_1.config["transport"],
     }
     config_overrides = {
         "interface": "127.0.0.2",
@@ -75,7 +84,7 @@ def salt_mm_master_2(salt_factories, salt_mm_master_1):
         "ret_port",
         "publish_port",
     ):
-        config_overrides[key] = salt_mm_master_1.config[key]
+        config_overrides[key] = _salt_mm_master_1.config[key]
     factory = salt_factories.salt_master_daemon(
         "mm-master-2",
         defaults=config_defaults,
@@ -87,28 +96,33 @@ def salt_mm_master_2(salt_factories, salt_mm_master_1):
     # because we need to clone the keys
     for keyfile in ("master.pem", "master.pub"):
         shutil.copyfile(
-            os.path.join(salt_mm_master_1.config["pki_dir"], keyfile),
+            os.path.join(_salt_mm_master_1.config["pki_dir"], keyfile),
             os.path.join(factory.config["pki_dir"], keyfile),
         )
-    with factory.started(start_timeout=120):
-        yield factory
+    yield factory
 
 
-@pytest.fixture(scope="package")
+@pytest.fixture
+def salt_mm_master_2(_salt_mm_master_2):
+    with _salt_mm_master_2.started(start_timeout=120):
+        yield _salt_mm_master_2
+
+
+@pytest.fixture
 def mm_master_2_salt_cli(salt_mm_master_2):
     return salt_mm_master_2.salt_cli(timeout=120)
 
 
 @pytest.fixture(scope="package")
-def salt_mm_minion_1(salt_mm_master_1, salt_mm_master_2):
+def _salt_mm_minion_1(_salt_mm_master_1, _salt_mm_master_2):
     config_defaults = {
-        "transport": salt_mm_master_1.config["transport"],
+        "transport": _salt_mm_master_1.config["transport"],
     }
 
-    mm_master_1_port = salt_mm_master_1.config["ret_port"]
-    mm_master_1_addr = salt_mm_master_1.config["interface"]
-    mm_master_2_port = salt_mm_master_2.config["ret_port"]
-    mm_master_2_addr = salt_mm_master_2.config["interface"]
+    mm_master_1_port = _salt_mm_master_1.config["ret_port"]
+    mm_master_1_addr = _salt_mm_master_1.config["interface"]
+    mm_master_2_port = _salt_mm_master_2.config["ret_port"]
+    mm_master_2_addr = _salt_mm_master_2.config["interface"]
     config_overrides = {
         "master": [
             f"{mm_master_1_addr}:{mm_master_1_port}",
@@ -126,26 +140,30 @@ def salt_mm_minion_1(salt_mm_master_1, salt_mm_master_2):
             "salt.utils.event": "debug",
         },
     }
-    factory = salt_mm_master_1.salt_minion_daemon(
+    yield _salt_mm_master_1.salt_minion_daemon(
         "mm-minion-1",
         defaults=config_defaults,
         overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=info"],
     )
-    with factory.started(start_timeout=120):
-        yield factory
+
+
+@pytest.fixture
+def salt_mm_minion_1(_salt_mm_minion_1, salt_mm_master_1, salt_mm_master_2):
+    with _salt_mm_minion_1.started(start_timeout=120):
+        yield _salt_mm_minion_1
 
 
 @pytest.fixture(scope="package")
-def salt_mm_minion_2(salt_mm_master_1, salt_mm_master_2):
+def _salt_mm_minion_2(_salt_mm_master_1, _salt_mm_master_2):
     config_defaults = {
-        "transport": salt_mm_master_1.config["transport"],
+        "transport": _salt_mm_master_1.config["transport"],
     }
 
-    mm_master_1_port = salt_mm_master_1.config["ret_port"]
-    mm_master_1_addr = salt_mm_master_1.config["interface"]
-    mm_master_2_port = salt_mm_master_2.config["ret_port"]
-    mm_master_2_addr = salt_mm_master_2.config["interface"]
+    mm_master_1_port = _salt_mm_master_1.config["ret_port"]
+    mm_master_1_addr = _salt_mm_master_1.config["interface"]
+    mm_master_2_port = _salt_mm_master_2.config["ret_port"]
+    mm_master_2_addr = _salt_mm_master_2.config["interface"]
     config_overrides = {
         "master": [
             f"{mm_master_1_addr}:{mm_master_1_port}",
@@ -163,17 +181,21 @@ def salt_mm_minion_2(salt_mm_master_1, salt_mm_master_2):
             "salt.utils.event": "debug",
         },
     }
-    factory = salt_mm_master_2.salt_minion_daemon(
+    yield _salt_mm_master_2.salt_minion_daemon(
         "mm-minion-2",
         defaults=config_defaults,
         overrides=config_overrides,
         extra_cli_arguments_after_first_start_failure=["--log-level=info"],
     )
-    with factory.started(start_timeout=120):
-        yield factory
 
 
-@pytest.fixture(scope="package")
+@pytest.fixture
+def salt_mm_minion_2(_salt_mm_minion_2, salt_mm_master_1, salt_mm_master_2):
+    with _salt_mm_minion_2.started(start_timeout=120):
+        yield _salt_mm_minion_2
+
+
+@pytest.fixture
 def run_salt_cmds():
     def _run_salt_cmds_fn(clis, minions):
         """
@@ -219,7 +241,7 @@ def run_salt_cmds():
     return _run_salt_cmds_fn
 
 
-@pytest.fixture(autouse=True)
+@pytest.fixture
 def ensure_connections(
     salt_mm_minion_1,
     salt_mm_minion_2,
@@ -229,6 +251,7 @@ def ensure_connections(
 ):
     # define the function
     def _ensure_connections_fn(clis, minions):
+        log.error("ENSURE CONNECTIONS - START")
         retries = 3
         while retries:
             returned = run_salt_cmds(clis, minions)
@@ -238,6 +261,7 @@ def ensure_connections(
             retries -= 1
         else:
             pytest.fail("Could not ensure the connections were okay.")
+        log.error("ENSURE CONNECTIONS - END")
 
     # run the function to ensure initial connections
     _ensure_connections_fn(
