@@ -5,6 +5,7 @@
 import logging
 
 import pytest  # pylint: disable=unused-import
+
 import salt.exceptions
 import salt.state
 import salt.utils.files
@@ -14,11 +15,14 @@ from tests.support.mock import MagicMock, patch
 log = logging.getLogger(__name__)
 
 
+pytestmark = [
+    pytest.mark.core_test,
+]
+
+
 @pytest.fixture
-def state_obj(tmp_path):
+def state_obj(minion_opts):
     with patch("salt.state.State._gather_pillar"):
-        minion_opts = salt.config.DEFAULT_MINION_OPTS.copy()
-        minion_opts["cachedir"] = str(tmp_path)
         yield salt.state.State(minion_opts)
 
 
@@ -31,7 +35,6 @@ def test_format_slots_no_slots(state_obj):
     assert cdata == {"args": ["arg"], "kwargs": {"key": "val"}}
 
 
-@pytest.mark.slow_test
 def test_format_slots_arg(state_obj):
     """
     Test the format slots is calling a slot specified in args with corresponding arguments.
@@ -47,7 +50,6 @@ def test_format_slots_arg(state_obj):
     assert cdata == {"args": ["fun_return"], "kwargs": {"key": "val"}}
 
 
-@pytest.mark.slow_test
 def test_format_slots_dict_arg(state_obj):
     """
     Test the format slots is calling a slot specified in dict arg.
@@ -63,7 +65,6 @@ def test_format_slots_dict_arg(state_obj):
     assert cdata == {"args": [{"subarg": "fun_return"}], "kwargs": {"key": "val"}}
 
 
-@pytest.mark.slow_test
 def test_format_slots_listdict_arg(state_obj):
     """
     Test the format slots is calling a slot specified in list containing a dict.
@@ -79,7 +80,6 @@ def test_format_slots_listdict_arg(state_obj):
     assert cdata == {"args": [[{"subarg": "fun_return"}]], "kwargs": {"key": "val"}}
 
 
-@pytest.mark.slow_test
 def test_format_slots_liststr_arg(state_obj):
     """
     Test the format slots is calling a slot specified in list containing a dict.
@@ -95,7 +95,6 @@ def test_format_slots_liststr_arg(state_obj):
     assert cdata == {"args": [["fun_return"]], "kwargs": {"key": "val"}}
 
 
-@pytest.mark.slow_test
 def test_format_slots_kwarg(state_obj):
     """
     Test the format slots is calling a slot specified in kwargs with corresponding arguments.
@@ -111,7 +110,6 @@ def test_format_slots_kwarg(state_obj):
     assert cdata == {"args": ["arg"], "kwargs": {"key": "fun_return"}}
 
 
-@pytest.mark.slow_test
 def test_format_slots_multi(state_obj):
     """
     Test the format slots is calling all slots with corresponding arguments when multiple slots
@@ -151,7 +149,6 @@ def test_format_slots_multi(state_obj):
     }
 
 
-@pytest.mark.slow_test
 def test_format_slots_malformed(state_obj):
     """
     Test the format slots keeps malformed slots untouched.
@@ -182,7 +179,6 @@ def test_format_slots_malformed(state_obj):
     assert cdata == sls_data
 
 
-@pytest.mark.slow_test
 def test_slot_traverse_dict(state_obj):
     """
     Test the slot parsing of dict response.
@@ -199,7 +195,6 @@ def test_slot_traverse_dict(state_obj):
     assert cdata == {"args": ["arg"], "kwargs": {"key": "value1"}}
 
 
-@pytest.mark.slow_test
 def test_slot_append(state_obj):
     """
     Test the slot parsing of dict response.
