@@ -1,3 +1,4 @@
+import logging
 import os
 
 import pytest
@@ -47,7 +48,7 @@ def test__clean_key_mismatch(key_data, linesep):
     assert crypt.clean_key(tst_key) != crypt.clean_key(chk_key)
 
 
-async def test_auth_aes_key_rotation(minion_root, io_loop):
+async def test_auth_aes_key_rotation(minion_root, io_loop, caplog):
     pki_dir = minion_root / "etc" / "salt" / "pki"
     opts = {
         "id": "minion",
@@ -83,8 +84,10 @@ async def test_auth_aes_key_rotation(minion_root, io_loop):
 
     assert credskey not in auth.creds_map
 
-    await auth.authenticate()
+    with caplog.at_level(logging.DEBUG):
+        await auth.authenticate()
 
+    assert "Got new master aes key" in caplog.text
     assert credskey in auth.creds_map
     assert auth.creds_map[credskey]["aes"] == aes
     assert auth.creds_map[credskey]["session"] == session
@@ -97,8 +100,10 @@ async def test_auth_aes_key_rotation(minion_root, io_loop):
         "session": session,
     }
 
-    await auth.authenticate()
+    with caplog.at_level(logging.DEBUG):
+        await auth.authenticate()
 
+    assert "The master's aes key has changed" in caplog.text
     assert credskey in auth.creds_map
     assert auth.creds_map[credskey]["aes"] == aes1
     assert auth.creds_map[credskey]["session"] == session
@@ -110,14 +115,16 @@ async def test_auth_aes_key_rotation(minion_root, io_loop):
         "session": session1,
     }
 
-    await auth.authenticate()
+    with caplog.at_level(logging.DEBUG):
+        await auth.authenticate()
 
+    assert "The master's session key has changed" in caplog.text
     assert credskey in auth.creds_map
     assert auth.creds_map[credskey]["aes"] == aes1
     assert auth.creds_map[credskey]["session"] == session1
 
 
-def test_sauth_aes_key_rotation(minion_root, io_loop):
+def test_sauth_aes_key_rotation(minion_root, io_loop, caplog):
 
     pki_dir = minion_root / "etc" / "salt" / "pki"
     opts = {
@@ -148,8 +155,10 @@ def test_sauth_aes_key_rotation(minion_root, io_loop):
 
     assert auth._creds is None
 
-    auth.authenticate()
+    with caplog.at_level(logging.DEBUG):
+        auth.authenticate()
 
+    assert "Got new master aes key" in caplog.text
     assert isinstance(auth._creds, dict)
     assert auth._creds["aes"] == aes
     assert auth._creds["session"] == session
@@ -162,8 +171,10 @@ def test_sauth_aes_key_rotation(minion_root, io_loop):
         "session": session,
     }
 
-    auth.authenticate()
+    with caplog.at_level(logging.DEBUG):
+        auth.authenticate()
 
+    assert "The master's aes key has changed" in caplog.text
     assert isinstance(auth._creds, dict)
     assert auth._creds["aes"] == aes1
     assert auth._creds["session"] == session
@@ -175,8 +186,10 @@ def test_sauth_aes_key_rotation(minion_root, io_loop):
         "session": session1,
     }
 
-    auth.authenticate()
+    with caplog.at_level(logging.DEBUG):
+        auth.authenticate()
 
+    assert "The master's session key has changed" in caplog.text
     assert isinstance(auth._creds, dict)
     assert auth._creds["aes"] == aes1
     assert auth._creds["session"] == session1
